//
//  ViewController.swift
//  Zinsrechner
//
//  Created by Holger Hinzberg on 13.06.17.
//  Copyright © 2017 Holger Hinzberg. All rights reserved.
//

import UIKit

class ViewController: UIViewController
{
    @IBOutlet var kontostandSchiebereglerLabel: UILabel!
    @IBOutlet var zinssatzSchiebereglerLabel: UILabel!
    @IBOutlet var laufzeitSchiebereglerLabel: UILabel!
    @IBOutlet var neuerKontostandLabel: UILabel!
    
    // Verbindungen zu den Schiebereglern
    @IBOutlet var kontostandSchieberegler: UISlider!
    @IBOutlet var zinssatzSchieberegler: UISlider!
    @IBOutlet var laufzeitSchieberegler: UISlider!
    
    // Ein NumberFormatter als Eigenschaft der Klasse
    var formatter: NumberFormatter?
        
    // Eigenschaften für die Werte der Schieberegler
    // Die Werte dürfen jetzt hier 0 sein
    var kontostand:Float = 0
    var zinssatz:Float = 0
    var laufzeit:Float = 0
    
    override func viewDidLoad()
    {
        super.viewDidLoad()
        
        // Die Werte der Schieberegler den
        // Eigenschaften der Klasse zuweisen
        self.kontostand = kontostandSchieberegler.value
        self.zinssatz = zinssatzSchieberegler.value
        self.laufzeit =  laufzeitSchieberegler.value
        
        // Ein Objekt der Klasse NumberFormatter erzeugen
        self.formatter = NumberFormatter()
        
        // Wir wollen Dezimalzahlen formatieren
        self.formatter?.numberStyle
            = NumberFormatter.Style.decimal
        
        // Die aktuellen Landeseinstellungen zuweisen
        self.formatter?.locale = Locale.current
        
        // Maximal und minimal zwei
        // Nachkommastellen sollen es sein
        self.formatter?.minimumFractionDigits = 2
        self.formatter?.maximumFractionDigits = 2
        
        var formatierterWert
            = self.formatter?.string(
                from: self.kontostand as NSNumber)
        
        self.kontostandSchiebereglerLabel.text
            = "\(formatierterWert!) €"
        
        formatierterWert
            = self.formatter?.string(
                from: self.zinssatz as NSNumber)
        
        self.zinssatzSchiebereglerLabel.text
            = "\(formatierterWert!) %"
        
        let wert = Int(self.laufzeit)
        
        if wert == 1
        {
            self.laufzeitSchiebereglerLabel.text = "1 Jahr"
        }
        else
        {
            self.laufzeitSchiebereglerLabel.text = "\(wert) Jahre"
        }
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    @IBAction func kontostandReglerBewegt(_ sender: UISlider)
    {
        // Werte des Schiebereglers in einer Eigenschaft ablegen
        self.kontostand = sender.value
        
        // Den eingestellten Wert des Schiebereglers auslesen
        let wert = sender.value
        
        // Den Zahlenwert in einen formatierten Text umwandeln
        let formatierterWert
            = self.formatter?.string(from: wert as NSNumber)
        
        // Den Wert in das Bezeichnungsfeld schreiben
        self.kontostandSchiebereglerLabel.text
            = "\(formatierterWert!) €"
        
        // Nach Änderung des Schiebereglers
        // den neuen Kontostand berechnen und anzeigen
        self.rechnen()
    }
    
    @IBAction func zinssatzReglerBewegt(_ sender: UISlider)
    {
        // Werte des Schiebereglers in einer Eigenschaft ablegen
        self.zinssatz = sender.value
        
        let wert = sender.value
        
        let formatierterWert
            = self.formatter?.string(from: wert as NSNumber)
        
        self.zinssatzSchiebereglerLabel.text
            = "\(formatierterWert!) %"
        
        // Nach Änderung des Schiebereglers
        // den neuen Kontostand berechnen und anzeigen
        self.rechnen()
    }
    
    @IBAction func laufzeitReglerBewegt(_ sender: UISlider)
    {
        // Werte des Schiebereglers in einer Eigenschaft ablegen
        self.laufzeit = sender.value
        
        // Den eingestellten wert holen und in
        // einen Int umwandeln
        let wert = Int(sender.value)
        
        if wert == 1
        {
            self.laufzeitSchiebereglerLabel.text = "1 Jahr"
        }
        else
        {
            self.laufzeitSchiebereglerLabel.text = "\(wert) Jahre"
        }
        
        // Nach Änderung des Schiebereglers
        // den neuen Kontostand berechnen und anzeigen
        self.rechnen()
    }
    
    // Methode zur Berechnung und zur Anzeige des
    // neuen Kontostandes
    func rechnen()
    {
	// Eine Instanz der Klasse erzeugen
        let zinsrechner = Zinsrechner()
        
        
        // Den neuen Kontostand berechnen
        let neuerKontostand = zinsrechner!.berechneZinsen(
            kontostand: Double(self.kontostand),
            zinssatz: Double(self.zinssatz),
            laufzeit: Int(self.laufzeit))
        
        // Wert in eine formatierte Zeichenkette umwandeln
        let formatierterWert
            = self.formatter?.string(
                from: neuerKontostand as NSNumber)
        
        // Das formatierte Ergebnis ausgeben
        self.neuerKontostandLabel.text
            = "\(formatierterWert!) €"
    }
}

